@@ -3,18 +3,13 @@
 # internal function to be used inside lav_optim_noniter
 # return 'x', the estimated vector of free parameters
 lav_sem_miiv_internal <- function(lavmodel = NULL, lavsamplestats = NULL,
-                                  lavpartable = NULL, lavpta = NULL,
+                                  lavpartable = NULL,
                                   lavdata = NULL, lavoptions = NULL) {
+  # this is the entry-point for MIIV estimation
+  lav_msg_note(gettext("** Estimator MIIV is still under development! **\n"))
 
-    # this is the entry-point for MIIV estimation
-    cat("\n")
-    cat("** Estimator MIIV is still under development! **\n")
-    cat("\n")
-
-    # return error (for now)
-    x <- as.numeric(NA)
-    class(x) <- "try-error"
-    x
+  # return error (for now)
+  x <- as.numeric(NA)
+  class(x) <- "try-error"
+  x
 }
-
-
